@@ -1,8 +1,5 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2011 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -24,18 +21,18 @@ template<typename T1>
 inline
 arma_warn_unused
 typename T1::elem_type
-det(const Base<typename T1::elem_type,T1>& X, const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0)
+det
+  (
+  const Base<typename T1::elem_type,T1>& X,
+  const bool slow = false,
+  const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
+  )
   {
   arma_extra_debug_sigprint();
   
-  typedef typename T1::elem_type eT;
+  arma_ignore(junk);
   
-  const unwrap<T1>   tmp(X.get_ref());
-  const Mat<eT>& A = tmp.M;
-  
-  arma_debug_check( !A.is_square(), "det(): matrix must be square" );
-  
-  return auxlib::det(A);
+  return auxlib::det(X, slow);
   }
 
 
@@ -45,19 +42,24 @@ template<typename T1>
 inline
 arma_warn_unused
 typename T1::elem_type
-det(const Op<T1, op_diagmat>& X)
+det
+  (
+  const Op<T1, op_diagmat>& X,
+  const bool slow = false
+  )
   {
   arma_extra_debug_sigprint();
+  arma_ignore(slow);
   
   typedef typename T1::elem_type eT;
   
   const diagmat_proxy<T1> A(X.m);
   
-  arma_debug_check( (A.n_elem == 0), "det(): given object has no elements" );
+  const u32 A_n_elem = A.n_elem;
   
-  eT val = A[0];
+  eT val = eT(1);
   
-  for(u32 i=1; i<A.n_elem; ++i)
+  for(u32 i=0; i<A_n_elem; ++i)
     {
     val *= A[i];
     }
@@ -72,14 +74,19 @@ template<typename T1>
 inline
 arma_warn_unused
 typename T1::elem_type
-det(const Op<T1,op_inv>& in, const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0)
+det
+  (
+  const Op<T1,op_inv>& in,
+  const bool slow = false,
+  const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
+  )
   {
   arma_extra_debug_sigprint();
+  arma_ignore(junk);
   
   typedef typename T1::elem_type eT;
-  isnt_fltpt<eT>::check();
   
-  eT tmp = det(in.m);
+  eT tmp = det(in.m, slow);
   arma_warn( (tmp == eT(0)), "det(): warning: denominator is zero" );
   
   return eT(1) / tmp;
@@ -92,16 +99,21 @@ template<typename T1>
 inline
 arma_warn_unused
 typename T1::elem_type
-det(const Op<T1,op_trans>& in, const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0)
+det
+  (
+  const Op<T1,op_htrans>& in,
+  const bool slow = false,
+  const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0)
   {
   arma_extra_debug_sigprint();
+  arma_ignore(junk);
   
   typedef typename T1::elem_type eT;
   
   const unwrap<T1>   tmp(in.m);
   const Mat<eT>& X = tmp.M;
-
-  return det(X);
+  
+  return det(X, slow);
   }
 
 
