@@ -1,7 +1,5 @@
-// Copyright (C) 2009 NICTA
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2011 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -17,94 +15,104 @@
 //! @{
 
 
-
-//! Generate a dense matrix with all elements set to random values with a gaussian distribution (zero mean, unit variance)
 inline
-const Op<mat, op_randn>
-randn(const u32 n_rows, const u32 n_cols)
+double
+randn()
   {
-  arma_extra_debug_sigprint();
-  
-  return Op<mat, op_randn>(n_rows, n_cols, 'j');
+  return double(eop_aux_randn<double>());
   }
 
 
-
-template<typename mat_type>
+template<typename eT>
 inline
-const Op<mat_type,op_randn>
-randn(const u32 n_rows, const u32 n_cols)
+typename arma_scalar_only<eT>::result
+randn()
   {
-  arma_extra_debug_sigprint();
-  
-  arma_type_check<is_Mat<mat_type>::value == false>::apply();
-  
-  return Op<mat_type,op_randn>(n_rows, n_cols, 'j');
+  return eT(eop_aux_randn<eT>());
   }
 
 
 
 //! Generate a vector with all elements set to random values with a gaussian distribution (zero mean, unit variance)
-inline
-const Op<colvec, op_randn>
+arma_inline
+const eOp<colvec, eop_randn>
 randn(const u32 n_elem)
   {
   arma_extra_debug_sigprint();
   
-  return Op<colvec, op_randn>(n_elem, 1, 'j');
+  return eOp<colvec, eop_randn>(n_elem, 1);
   }
 
 
 
 template<typename vec_type>
-inline
-const Op<vec_type,op_randn>
-randn(const u32 n_elem)
+arma_inline
+const eOp<vec_type, eop_randn>
+randn(const u32 n_elem, const arma_empty_class junk1 = arma_empty_class(), const typename arma_Mat_Col_Row_only<vec_type>::result* junk2 = 0)
   {
   arma_extra_debug_sigprint();
-  
-  arma_type_check< (is_Col<vec_type>::value == false) && (is_Row<vec_type>::value == false) >::apply();
+  arma_ignore(junk1);
+  arma_ignore(junk2);
   
   if(is_Row<vec_type>::value == true)
     {
-    return Op<vec_type,op_randn>(1, n_elem, 'j');
+    return eOp<vec_type, eop_randn>(1, n_elem);
     }
   else
     {
-    return Op<vec_type,op_randn>(n_elem, 1, 'j');
+    return eOp<vec_type, eop_randn>(n_elem, 1);
     }
   }
 
 
 
-//
-//
-// handling of cubes
+//! Generate a dense matrix with all elements set to random values with a gaussian distribution (zero mean, unit variance)
+arma_inline
+const eOp<mat, eop_randn>
+randn(const u32 n_rows, const u32 n_cols)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOp<mat, eop_randn>(n_rows, n_cols);
+  }
 
 
 
-//! Generate a dense cube with all elements set to random values with a gaussian distribution (zero mean, unit variance)
-inline
-const OpCube<cube, op_randn>
+template<typename mat_type>
+arma_inline
+const eOp<mat_type, eop_randn>
+randn(const u32 n_rows, const u32 n_cols, const typename arma_Mat_Col_Row_only<mat_type>::result* junk = 0)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_ignore(junk);
+  
+  return eOp<mat_type, eop_randn>(n_rows, n_cols);
+  }
+
+
+
+arma_inline
+const eOpCube<cube, eop_randn>
 randn(const u32 n_rows, const u32 n_cols, const u32 n_slices)
   {
   arma_extra_debug_sigprint();
   
-  return OpCube<cube, op_randn>(n_rows, n_cols, n_slices);
+  return eOpCube<cube, eop_randn>(n_rows, n_cols, n_slices);
   }
 
 
 
 template<typename cube_type>
-inline
-const OpCube<cube_type,op_randn>
-randn(const u32 n_rows, const u32 n_cols, const u32 n_slices)
+arma_inline
+const eOpCube<cube_type, eop_randn>
+randn(const u32 n_rows, const u32 n_cols, const u32 n_slices, const typename arma_Cube_only<cube_type>::result* junk = 0)
   {
   arma_extra_debug_sigprint();
   
-  arma_type_check<is_Cube<cube_type>::value == false>::apply();
+  arma_ignore(junk);
   
-  return OpCube<cube_type,op_randn>(n_rows, n_cols, n_slices);
+  return eOpCube<cube_type, eop_randn>(n_rows, n_cols, n_slices);
   }
 
 
